@@ -211,3 +211,13 @@ class TcSoaBasics:
     def set_object_load_policy(cls, bo_name: str, properties: List[str]):
         rest_backend: RestBackend = TcSoaConfig.backend
         rest_backend.set_object_load_policy(bo_name, properties)
+
+    @classmethod
+    def get_cached_obj(cls, uid: str):
+        obj = TcSoaConfig.internal_get_obj(uid)
+        if obj is not None:
+            bo = BusinessObject()
+            bo.uid = bo.objectID = obj['uid']
+            bo.type = bo.className = obj['type']
+            return bo
+        return None
